@@ -32,6 +32,9 @@ typedef struct ogs_sbi_server_s ogs_sbi_server_t;
 typedef struct ogs_sbi_client_s ogs_sbi_client_t;
 typedef struct ogs_sbi_header_s ogs_sbi_header_t;
 
+char *ogs_supi_from_suci(char *suci);
+char *ogs_supi_from_supi_or_suci(char *supi_or_suci);
+
 char *ogs_uridup(bool https, ogs_sockaddr_t *addr, ogs_sbi_header_t *h);
 char *ogs_sbi_server_uri(ogs_sbi_server_t *server, ogs_sbi_header_t *h);
 char *ogs_sbi_client_apiroot(ogs_sbi_client_t *client);
@@ -39,8 +42,9 @@ char *ogs_sbi_client_uri(ogs_sbi_client_t *client, ogs_sbi_header_t *h);
 
 char *ogs_sbi_parse_uri(char *uri, const char *delim, char **saveptr);
 
-ogs_sockaddr_t *ogs_sbi_getaddr_from_uri(char *uri);
-char *ogs_sbi_getpath_from_uri(char *uri);
+bool ogs_sbi_getaddr_from_uri(
+        OpenAPI_uri_scheme_e *scheme, ogs_sockaddr_t **addr, char *uri);
+bool ogs_sbi_getpath_from_uri(char **path, char *uri);
 
 #define OGS_SBI_BITRATE_BPS     0
 #define OGS_SBI_BITRATE_KBPS    1
@@ -87,6 +91,7 @@ OpenAPI_pcc_rule_t *ogs_sbi_build_pcc_rule(
 void ogs_sbi_free_pcc_rule(OpenAPI_pcc_rule_t *PccRule);
 OpenAPI_qos_data_t *ogs_sbi_build_qos_data(ogs_pcc_rule_t *pcc_rule);
 void ogs_sbi_free_qos_data(OpenAPI_qos_data_t *QosData);
+char *ogs_sbi_s_nssai_to_string_plain(ogs_s_nssai_t *s_nssai);
 
 #ifdef __cplusplus
 }
