@@ -188,7 +188,6 @@ OpenAPI_assigned_ebi_data_t *OpenAPI_assigned_ebi_data_parseFromJSON(cJSON *assi
             OpenAPI_ebi_arp_mapping_t *assigned_ebi_listItem = OpenAPI_ebi_arp_mapping_parseFromJSON(assigned_ebi_list_local);
             if (!assigned_ebi_listItem) {
                 ogs_error("No assigned_ebi_listItem");
-                OpenAPI_list_free(assigned_ebi_listList);
                 goto end;
             }
             OpenAPI_list_add(assigned_ebi_listList, assigned_ebi_listItem);
@@ -212,7 +211,6 @@ OpenAPI_assigned_ebi_data_t *OpenAPI_assigned_ebi_data_parseFromJSON(cJSON *assi
             OpenAPI_arp_t *failed_arp_listItem = OpenAPI_arp_parseFromJSON(failed_arp_list_local);
             if (!failed_arp_listItem) {
                 ogs_error("No failed_arp_listItem");
-                OpenAPI_list_free(failed_arp_listList);
                 goto end;
             }
             OpenAPI_list_add(failed_arp_listList, failed_arp_listItem);
