@@ -28,24 +28,32 @@ OpenAPI_sequence_number_t *OpenAPI_sequence_number_create(
 
 void OpenAPI_sequence_number_free(OpenAPI_sequence_number_t *sequence_number)
 {
+    OpenAPI_lnode_t *node = NULL;
+
     if (NULL == sequence_number) {
         return;
     }
-    OpenAPI_lnode_t *node;
-    ogs_free(sequence_number->sqn);
-    OpenAPI_list_for_each(sequence_number->last_indexes, node) {
-        OpenAPI_map_t *localKeyValue = (OpenAPI_map_t*)node->data;
-        ogs_free(localKeyValue->key);
-        ogs_free(localKeyValue->value);
-        ogs_free(localKeyValue);
+    if (sequence_number->sqn) {
+        ogs_free(sequence_number->sqn);
+        sequence_number->sqn = NULL;
+    }
+    if (sequence_number->last_indexes) {
+        OpenAPI_list_for_each(sequence_number->last_indexes, node) {
+            OpenAPI_map_t *localKeyValue = (OpenAPI_map_t*)node->data;
+            ogs_free(localKeyValue->key);
+            ogs_free(localKeyValue->value);
+            OpenAPI_map_free(localKeyValue);
+        }
+        OpenAPI_list_free(sequence_number->last_indexes);
+        sequence_number->last_indexes = NULL;
     }
-    OpenAPI_list_free(sequence_number->last_indexes);
     ogs_free(sequence_number);
 }
 
 cJSON *OpenAPI_sequence_number_convertToJSON(OpenAPI_sequence_number_t *sequence_number)
 {
     cJSON *item = NULL;
+    OpenAPI_lnode_t *node = NULL;
 
     if (sequence_number == NULL) {
         ogs_error("OpenAPI_sequence_number_convertToJSON() failed [SequenceNumber]");
@@ -53,7 +61,7 @@ cJSON *OpenAPI_sequence_number_convertToJSON(OpenAPI_sequence_number_t *sequence
     }
 
     item = cJSON_CreateObject();
-    if (sequence_number->sqn_scheme) {
+    if (sequence_number->sqn_scheme != OpenAPI_sqn_scheme_NULL) {
     if (cJSON_AddStringToObject(item, "sqnScheme", OpenAPI_sqn_scheme_ToString(sequence_number->sqn_scheme)) == NULL) {
         ogs_error("OpenAPI_sequence_number_convertToJSON() failed [sqn_scheme]");
         goto end;
@@ -74,13 +82,16 @@ cJSON *OpenAPI_sequence_number_convertToJSON(OpenAPI_sequence_number_t *sequence
         goto end;
     }
     cJSON *localMapObject = last_indexes;
-    OpenAPI_lnode_t *last_indexes_node;
     if (sequence_number->last_indexes) {
-        OpenAPI_list_for_each(sequence_number->last_indexes, last_indexes_node) {
-            OpenAPI_map_t *localKeyValue = (OpenAPI_map_t*)last_indexes_node->data;
+        OpenAPI_list_for_each(sequence_number->last_indexes, node) {
+            OpenAPI_map_t *localKeyValue = (OpenAPI_map_t*)node->data;
+            if (cJSON_AddNumberToObject(localMapObject, localKeyValue->key, (uintptr_t)localKeyValue->value) == NULL) {
+                ogs_error("OpenAPI_sequence_number_convertToJSON() failed [inner]");
+                goto end;
             }
         }
     }
+    }
 
     if (sequence_number->is_ind_length) {
     if (cJSON_AddNumberToObject(item, "indLength", sequence_number->ind_length) == NULL) {
@@ -89,7 +100,7 @@ cJSON *OpenAPI_sequence_number_convertToJSON(OpenAPI_sequence_number_t *sequence
     }
     }
 
-    if (sequence_number->dif_sign) {
+    if (sequence_number->dif_sign != OpenAPI_sign_NULL) {
     if (cJSON_AddStringToObject(item, "difSign", OpenAPI_sign_ToString(sequence_number->dif_sign)) == NULL) {
         ogs_error("OpenAPI_sequence_number_convertToJSON() failed [dif_sign]");
         goto end;
@@ -103,9 +114,16 @@ end:
 OpenAPI_sequence_number_t *OpenAPI_sequence_number_parseFromJSON(cJSON *sequence_numberJSON)
 {
     OpenAPI_sequence_number_t *sequence_number_local_var = NULL;
-    cJSON *sqn_scheme = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "sqnScheme");
-
-    OpenAPI_sqn_scheme_e sqn_schemeVariable;
+    OpenAPI_lnode_t *node = NULL;
+    cJSON *sqn_scheme = NULL;
+    OpenAPI_sqn_scheme_e sqn_schemeVariable = 0;
+    cJSON *sqn = NULL;
+    cJSON *last_indexes = NULL;
+    OpenAPI_list_t *last_indexesList = NULL;
+    cJSON *ind_length = NULL;
+    cJSON *dif_sign = NULL;
+    OpenAPI_sign_e dif_signVariable = 0;
+    sqn_scheme = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "sqnScheme");
     if (sqn_scheme) {
     if (!cJSON_IsString(sqn_scheme)) {
         ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [sqn_scheme]");
@@ -114,34 +132,45 @@ OpenAPI_sequence_number_t *OpenAPI_sequence_number_parseFromJSON(cJSON *sequence
     sqn_schemeVariable = OpenAPI_sqn_scheme_FromString(sqn_scheme->valuestring);
     }
 
-    cJSON *sqn = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "sqn");
-
+    sqn = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "sqn");
     if (sqn) {
-    if (!cJSON_IsString(sqn)) {
+    if (!cJSON_IsString(sqn) && !cJSON_IsNull(sqn)) {
         ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [sqn]");
         goto end;
     }
     }
 
-    cJSON *last_indexes = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "lastIndexes");
-
-    OpenAPI_list_t *last_indexesList;
+    last_indexes = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "lastIndexes");
     if (last_indexes) {
-    cJSON *last_indexes_local_map;
-    if (!cJSON_IsObject(last_indexes)) {
-        ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [last_indexes]");
-        goto end;
-    }
-    last_indexesList = OpenAPI_list_create();
-    OpenAPI_map_t *localMapKeyPair = NULL;
-    cJSON_ArrayForEach(last_indexes_local_map, last_indexes) {
-        cJSON *localMapObject = last_indexes_local_map;
-        OpenAPI_list_add(last_indexesList , localMapKeyPair);
-    }
+        cJSON *last_indexes_local_map = NULL;
+        if (!cJSON_IsObject(last_indexes) && !cJSON_IsNull(last_indexes)) {
+            ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [last_indexes]");
+            goto end;
+        }
+        if (cJSON_IsObject(last_indexes)) {
+            last_indexesList = OpenAPI_list_create();
+            OpenAPI_map_t *localMapKeyPair = NULL;
+            cJSON_ArrayForEach(last_indexes_local_map, last_indexes) {
+                cJSON *localMapObject = last_indexes_local_map;
+                double *localDouble = NULL;
+                int *localInt = NULL;
+                if (!cJSON_IsNumber(localMapObject)) {
+                    ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [inner]");
+                    goto end;
+                }
+                localDouble = (double *)ogs_calloc(1, sizeof(double));
+                if (!localDouble) {
+                    ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [inner]");
+                    goto end;
+                }
+                *localDouble = localMapObject->valuedouble;
+                localMapKeyPair = OpenAPI_map_create(ogs_strdup(localMapObject->string), localDouble);
+                OpenAPI_list_add(last_indexesList, localMapKeyPair);
+            }
+        }
     }
 
-    cJSON *ind_length = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "indLength");
-
+    ind_length = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "indLength");
     if (ind_length) {
     if (!cJSON_IsNumber(ind_length)) {
         ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [ind_length]");
@@ -149,9 +178,7 @@ OpenAPI_sequence_number_t *OpenAPI_sequence_number_parseFromJSON(cJSON *sequence
     }
     }
 
-    cJSON *dif_sign = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "difSign");
-
-    OpenAPI_sign_e dif_signVariable;
+    dif_sign = cJSON_GetObjectItemCaseSensitive(sequence_numberJSON, "difSign");
     if (dif_sign) {
     if (!cJSON_IsString(dif_sign)) {
         ogs_error("OpenAPI_sequence_number_parseFromJSON() failed [dif_sign]");
@@ -162,7 +189,7 @@ OpenAPI_sequence_number_t *OpenAPI_sequence_number_parseFromJSON(cJSON *sequence
 
     sequence_number_local_var = OpenAPI_sequence_number_create (
         sqn_scheme ? sqn_schemeVariable : 0,
-        sqn ? ogs_strdup(sqn->valuestring) : NULL,
+        sqn && !cJSON_IsNull(sqn) ? ogs_strdup(sqn->valuestring) : NULL,
         last_indexes ? last_indexesList : NULL,
         ind_length ? true : false,
         ind_length ? ind_length->valuedouble : 0,
@@ -171,6 +198,16 @@ OpenAPI_sequence_number_t *OpenAPI_sequence_number_parseFromJSON(cJSON *sequence
 
     return sequence_number_local_var;
 end:
+    if (last_indexesList) {
+        OpenAPI_list_for_each(last_indexesList, node) {
+            OpenAPI_map_t *localKeyValue = (OpenAPI_map_t*) node->data;
+            ogs_free(localKeyValue->key);
+            ogs_free(localKeyValue->value);
+            OpenAPI_map_free(localKeyValue);
+        }
+        OpenAPI_list_free(last_indexesList);
+        last_indexesList = NULL;
+    }
     return NULL;
 }
 
