@@ -27,8 +27,7 @@ int nas_5gs_send_to_gnb(amf_ue_t *amf_ue, ogs_pkbuf_t *pkbuf)
     int rv;
     ogs_assert(pkbuf);
 
-    amf_ue = amf_ue_cycle(amf_ue);
-    if (!amf_ue) {
+    if (!amf_ue_cycle(amf_ue)) {
         ogs_error("UE(amf-ue) context has already been removed");
         ogs_pkbuf_free(pkbuf);
         return OGS_NOTFOUND;
@@ -48,8 +47,7 @@ int nas_5gs_send_to_downlink_nas_transport(amf_ue_t *amf_ue, ogs_pkbuf_t *pkbuf)
 
     ogs_assert(pkbuf);
 
-    amf_ue = amf_ue_cycle(amf_ue);
-    if (!amf_ue) {
+    if (!amf_ue_cycle(amf_ue)) {
         ogs_error("UE(amf-ue) context has already been removed");
         ogs_pkbuf_free(pkbuf);
         return OGS_NOTFOUND;
@@ -85,7 +83,11 @@ int nas_5gs_send_registration_accept(amf_ue_t *amf_ue)
     ogs_pkbuf_t *ngapbuf = NULL;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     ran_ue = ran_ue_cycle(amf_ue->ran_ue);
     if (!ran_ue) {
         ogs_error("NG context has already been removed");
@@ -187,9 +189,32 @@ int nas_5gs_send_registration_reject(
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    amf_metrics_inst_by_cause_add(gmm_cause, AMF_METR_CTR_RM_REG_INITFAIL, 1);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
-    ogs_assert(amf_ue);
+    switch (amf_ue->nas.registration.value) {
+    case OGS_NAS_5GS_REGISTRATION_TYPE_INITIAL:
+        amf_metrics_inst_by_cause_add(gmm_cause,
+                AMF_METR_CTR_RM_REG_INIT_FAIL, 1);
+        break;
+    case OGS_NAS_5GS_REGISTRATION_TYPE_MOBILITY_UPDATING:
+        amf_metrics_inst_by_cause_add(gmm_cause,
+                AMF_METR_CTR_RM_REG_MOB_FAIL, 1);
+        break;
+    case OGS_NAS_5GS_REGISTRATION_TYPE_PERIODIC_UPDATING:
+        amf_metrics_inst_by_cause_add(gmm_cause,
+                AMF_METR_CTR_RM_REG_PERIOD_FAIL, 1);
+        break;
+    case OGS_NAS_5GS_REGISTRATION_TYPE_EMERGENCY:
+        amf_metrics_inst_by_cause_add(gmm_cause,
+                AMF_METR_CTR_RM_REG_EMERG_FAIL, 1);
+        break;
+    default:
+        ogs_error("Unknown reg_type[%d]",
+                amf_ue->nas.registration.value);
+    }
 
     ogs_warn("[%s] Registration reject [%d]", amf_ue->suci, gmm_cause);
 
@@ -214,7 +239,11 @@ int nas_5gs_send_service_accept(amf_ue_t *amf_ue)
     ogs_pkbuf_t *gmmbuf = NULL;
     ogs_pkbuf_t *ngapbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     ran_ue = ran_ue_cycle(amf_ue->ran_ue);
     if (!ran_ue) {
         ogs_error("NG context has already been removed");
@@ -288,7 +317,15 @@ int nas_5gs_send_service_reject(
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_debug("[%s] Service reject", amf_ue->supi);
 
@@ -311,7 +348,11 @@ int nas_5gs_send_de_registration_accept(amf_ue_t *amf_ue)
     ran_ue_t *ran_ue = NULL;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     ran_ue = ran_ue_cycle(amf_ue->ran_ue);
     if (!ran_ue) {
         ogs_error("NG context has already been removed");
@@ -344,15 +385,21 @@ int nas_5gs_send_de_registration_accept(amf_ue_t *amf_ue)
     return rv;
 }
 
-int nas_5gs_send_de_registration_request(amf_ue_t *amf_ue,
-        OpenAPI_deregistration_reason_e dereg_reason)
+int nas_5gs_send_de_registration_request(
+        amf_ue_t *amf_ue,
+        OpenAPI_deregistration_reason_e dereg_reason,
+        ogs_nas_5gmm_cause_t gmm_cause)
 {
     int rv;
 
     ran_ue_t *ran_ue = NULL;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     ran_ue = ran_ue_cycle(amf_ue->ran_ue);
     if (!ran_ue) {
         ogs_error("NG context has already been removed");
@@ -364,7 +411,8 @@ int nas_5gs_send_de_registration_request(amf_ue_t *amf_ue,
     if (amf_ue->t3522.pkbuf) {
         gmmbuf = amf_ue->t3522.pkbuf;
     } else {
-        gmmbuf = gmm_build_de_registration_request(amf_ue, dereg_reason);
+        gmmbuf = gmm_build_de_registration_request(
+                amf_ue, dereg_reason, gmm_cause);
         if (!gmmbuf) {
             ogs_error("gmm_build_de_registration_request() failed");
             return OGS_ERROR;
@@ -391,7 +439,15 @@ int nas_5gs_send_identity_request(amf_ue_t *amf_ue)
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_debug("Identity request");
 
@@ -425,7 +481,15 @@ int nas_5gs_send_authentication_request(amf_ue_t *amf_ue)
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_debug("[%s] Authentication request", amf_ue->suci);
 
@@ -448,6 +512,8 @@ int nas_5gs_send_authentication_request(amf_ue_t *amf_ue)
     ogs_timer_start(amf_ue->t3560.timer,
             amf_timer_cfg(AMF_TIMER_T3560)->duration);
 
+    amf_metrics_inst_global_inc(AMF_METR_GLOB_CTR_AMF_AUTH_REQ);
+
     rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
@@ -459,9 +525,15 @@ int nas_5gs_send_authentication_reject(amf_ue_t *amf_ue)
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    amf_metrics_inst_by_cause_add(0, AMF_METR_CTR_RM_REG_INITFAIL, 1);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
-    ogs_assert(amf_ue);
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_warn("[%s] Authentication reject", amf_ue->suci);
 
@@ -471,6 +543,8 @@ int nas_5gs_send_authentication_reject(amf_ue_t *amf_ue)
         return OGS_ERROR;
     }
 
+    amf_metrics_inst_global_inc(AMF_METR_GLOB_CTR_AMF_AUTH_REJECT);
+
     rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
@@ -482,7 +556,15 @@ int nas_5gs_send_security_mode_command(amf_ue_t *amf_ue)
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_debug("[%s] Security mode command", amf_ue->supi);
 
@@ -517,7 +599,15 @@ int nas_5gs_send_configuration_update_command(
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_info("[%s] Configuration update command", amf_ue->supi);
 
@@ -556,6 +646,8 @@ int nas_5gs_send_configuration_update_command(
         }
     }
 
+    amf_metrics_inst_global_inc(AMF_METR_GLOB_CTR_MM_CONF_UPDATE);
+
     rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
@@ -764,10 +856,25 @@ int nas_send_pdu_session_release_command(amf_sess_t *sess,
         rv = nas_5gs_send_to_gnb(amf_ue, ngapbuf);
         ogs_expect(rv == OGS_OK);
     } else {
-        ogs_error("ngap_build_pdu_session_resource_release_command() failed");
-        ogs_error("    ACTIVATED[0x%x] SUPI[%s] PSI[%d]",
-                ran_ue->psimask.activated, amf_ue->supi, sess->psi);
-        return OGS_ERROR;
+        /*
+         * TS23.527
+         * 5.3 Restoration Procedures upon Loss of GTP-U contexts
+         * 5.3.2 Procedure for GTP-U Error Indication received from 5G-AN
+         *
+         * 1. gNB sent TP-U Error Indication to the UPF.
+         * 2. UPF sent PFCP Report to SMF.
+         * 3. SMF sent N1N2Transfer to AMF to release PDU Session
+         * 4. In AMF, there is no Activated Session.
+         *
+         * Since AMF does not yet have an activated PDU Session,
+         * it ignores it without requesting PDU release from gNB.
+         */
+        ogs_error("No session and N1 message");
+        ogs_error("    ACTIVATED[0x%x] N1[%p], SUPI[%s] PSI[%d]",
+                ran_ue->psimask.activated, gmmbuf, amf_ue->supi, sess->psi);
+
+        ogs_pkbuf_free(n2smbuf);
+        rv = OGS_OK;
     }
 
     return rv;
@@ -778,7 +885,15 @@ int nas_5gs_send_gmm_status(amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t cause)
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_debug("[%s] 5GMM status", amf_ue->supi);
 
@@ -798,7 +913,16 @@ int nas_5gs_send_gmm_reject(
         amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
 {
     int rv;
-    ogs_assert(amf_ue);
+
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     switch(amf_ue->nas.message_type) {
     case OGS_NAS_5GS_REGISTRATION_REQUEST:
@@ -846,7 +970,16 @@ int nas_5gs_send_gmm_reject_from_sbi(amf_ue_t *amf_ue, int status)
 {
     int rv;
 
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     rv = nas_5gs_send_gmm_reject(amf_ue, gmm_cause_from_sbi(status));
     ogs_expect(rv == OGS_OK);
 
@@ -863,8 +996,17 @@ int nas_5gs_send_dl_nas_transport(amf_sess_t *sess,
     amf_ue_t *amf_ue = NULL;
 
     ogs_assert(sess);
+
     amf_ue = sess->amf_ue;
-    ogs_assert(amf_ue);
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
 
     ogs_assert(payload_container_type);
     ogs_assert(payload_container);
@@ -900,8 +1042,21 @@ int nas_5gs_send_gsm_reject(amf_sess_t *sess,
         uint8_t payload_container_type, ogs_pkbuf_t *payload_container)
 {
     int rv;
+    amf_ue_t *amf_ue = NULL;
 
     ogs_assert(sess);
+
+    amf_ue = sess->amf_ue;
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     ogs_assert(payload_container_type);
     ogs_assert(payload_container);
 
@@ -917,8 +1072,21 @@ int nas_5gs_send_back_gsm_message(
 {
     int rv;
     ogs_pkbuf_t *pbuf = NULL;
+    amf_ue_t *amf_ue = NULL;
 
     ogs_assert(sess);
+
+    amf_ue = sess->amf_ue;
+    if (!amf_ue_cycle(amf_ue)) {
+        ogs_error("UE(amf-ue) context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
+    if (!ran_ue_cycle(amf_ue->ran_ue)) {
+        ogs_error("NG context has already been removed");
+        return OGS_NOTFOUND;
+    }
+
     ogs_assert(sess->payload_container_type);
     ogs_assert(sess->payload_container);
 
