@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2022 by Sukchan Lee <acetcom@gmail.com>
+ * Copyright (C) 2019-2023 by Sukchan Lee <acetcom@gmail.com>
  *
  * This file is part of Open5GS.
  *
@@ -218,9 +218,22 @@ void ausf_state_operational(ogs_fsm_t *s, ausf_event_t *e)
                         message.res_status == OGS_SBI_HTTP_STATUS_OK) {
                         ogs_nnrf_nfm_handle_nf_status_subscribe(
                                 subscription_data, &message);
+                    } else {
+                        ogs_error("HTTP response error : %d",
+                                message.res_status);
+                    }
+                    break;
+
+                CASE(OGS_SBI_HTTP_METHOD_PATCH)
+                    if (message.res_status == OGS_SBI_HTTP_STATUS_OK ||
+                        message.res_status == OGS_SBI_HTTP_STATUS_NO_CONTENT) {
+                        ogs_nnrf_nfm_handle_nf_status_update(
+                                subscription_data, &message);
                     } else {
                         ogs_error("[%s] HTTP response error [%d]",
-                                subscription_data->id, message.res_status);
+                                subscription_data->id ?
+                                    subscription_data->id : "Unknown",
+                                message.res_status);
                     }
                     break;
 
@@ -230,7 +243,9 @@ void ausf_state_operational(ogs_fsm_t *s, ausf_event_t *e)
                         ogs_sbi_subscription_data_remove(subscription_data);
                     } else {
                         ogs_error("[%s] HTTP response error [%d]",
-                                subscription_data->id, message.res_status);
+                                subscription_data->id ?
+                                    subscription_data->id : "Unknown",
+                                message.res_status);
                     }
                     break;
 
@@ -352,11 +367,22 @@ void ausf_state_operational(ogs_fsm_t *s, ausf_event_t *e)
                     subscription_data->subscr_cond.nf_type,
                     subscription_data->subscr_cond.service_name));
 
-            ogs_info("Subscription validity expired [%s]",
+            ogs_error("[%s] Subscription validity expired",
                 subscription_data->id);
             ogs_sbi_subscription_data_remove(subscription_data);
             break;
 
+        case OGS_TIMER_SUBSCRIPTION_PATCH:
+            subscription_data = e->h.sbi.data;
+            ogs_assert(subscription_data);
+
+            ogs_assert(true ==
+                ogs_nnrf_nfm_send_nf_status_update(subscription_data));
+
+            ogs_info("[%s] Need to update Subscription",
+                    subscription_data->id);
+            break;
+
         case OGS_TIMER_SBI_CLIENT_WAIT:
             /*
              * ogs_pollset_poll() receives the time of the expiration
