@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 by Sukchan Lee <acetcom@gmail.com>
+ * Copyright (C) 2019-2023 by Sukchan Lee <acetcom@gmail.com>
  *
  * This file is part of Open5GS.
  *
@@ -258,11 +258,13 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
 {
     int len;
     ssize_t size;
-    char buf[OGS_ADDRSTRLEN];
+    char buf1[OGS_ADDRSTRLEN];
+    char buf2[OGS_ADDRSTRLEN];
 
     upf_sess_t *sess = NULL;
 
     ogs_pkbuf_t *pkbuf = NULL;
+    ogs_sock_t *sock = NULL;
     ogs_sockaddr_t from;
 
     ogs_gtp2_header_t *gtp_h = NULL;
@@ -272,6 +274,8 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
     uint8_t qfi;
 
     ogs_assert(fd != INVALID_SOCKET);
+    sock = data;
+    ogs_assert(sock);
 
     pkbuf = ogs_pkbuf_alloc(packet_pool, OGS_MAX_PKT_LEN);
     ogs_assert(pkbuf);
@@ -300,14 +304,14 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
     if (gtp_h->type == OGS_GTPU_MSGTYPE_ECHO_REQ) {
         ogs_pkbuf_t *echo_rsp;
 
-        ogs_debug("[RECV] Echo Request from [%s]", OGS_ADDR(&from, buf));
+        ogs_debug("[RECV] Echo Request from [%s]", OGS_ADDR(&from, buf1));
         echo_rsp = ogs_gtp2_handle_echo_req(pkbuf);
         ogs_expect(echo_rsp);
         if (echo_rsp) {
             ssize_t sent;
 
             /* Echo reply */
-            ogs_debug("[SEND] Echo Response to [%s]", OGS_ADDR(&from, buf));
+            ogs_debug("[SEND] Echo Response to [%s]", OGS_ADDR(&from, buf1));
 
             sent = ogs_sendto(fd, echo_rsp->data, echo_rsp->len, 0, &from);
             if (sent < 0 || sent != echo_rsp->len) {
@@ -322,7 +326,7 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
     teid = be32toh(gtp_h->teid);
 
     ogs_trace("[RECV] GPU-U Type [%d] from [%s] : TEID[0x%x]",
-            gtp_h->type, OGS_ADDR(&from, buf), teid);
+            gtp_h->type, OGS_ADDR(&from, buf1), teid);
 
     qfi = 0;
     if (gtp_h->flags & OGS_GTPU_FLAGS_E) {
@@ -369,7 +373,7 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
     } else if (gtp_h->type == OGS_GTPU_MSGTYPE_ERR_IND) {
         ogs_pfcp_far_t *far = NULL;
 
-        far = ogs_pfcp_far_find_by_error_indication(pkbuf);
+        far = ogs_pfcp_far_find_by_gtpu_error_indication(pkbuf);
         if (far) {
             ogs_assert(true ==
                 ogs_pfcp_up_handle_error_indication(far, &report));
@@ -419,12 +423,32 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
 
         pfcp_object = ogs_pfcp_object_find_by_teid(teid);
         if (!pfcp_object) {
-            /* TODO : Send Error Indication */
+            /*
+             * TS23.527 Restoration procedures
+             * 4.3 UPF Restoration Procedures
+             * 4.3.2 Restoration Procedure for PSA UPF Restart
+             *
+             * The UPF shall not send GTP-U Error indication message
+             * for a configurable period after an UPF restart
+             * when the UPF receives a G-PDU not matching any PDRs.
+             */
+            if (ogs_time_ntp32_now() >
+                   (ogs_pfcp_self()->local_recovery +
+                    ogs_time_sec(
+                        ogs_app()->time.message.pfcp.association_interval))) {
+                ogs_error("[%s] Send Error Indication [TEID:0x%x] to [%s]",
+                        OGS_ADDR(&sock->local_addr, buf1),
+                        teid,
+                        OGS_ADDR(&from, buf2));
+                ogs_gtp1_send_error_indication(sock, teid, qfi, &from);
+            }
             goto cleanup;
         }
 
         switch(pfcp_object->type) {
         case OGS_PFCP_OBJ_PDR_TYPE:
+            /* UPF does not use PDR TYPE */
+            ogs_assert_if_reached();
             pdr = (ogs_pfcp_pdr_t *)pfcp_object;
             ogs_assert(pdr);
             break;
@@ -456,7 +480,26 @@ static void _gtpv1_u_recv_cb(short when, ogs_socket_t fd, void *data)
             }
 
             if (!pdr) {
-                /* TODO : Send Error Indication */
+                /*
+                 * TS23.527 Restoration procedures
+                 * 4.3 UPF Restoration Procedures
+                 * 4.3.2 Restoration Procedure for PSA UPF Restart
+                 *
+                 * The UPF shall not send GTP-U Error indication message
+                 * for a configurable period after an UPF restart
+                 * when the UPF receives a G-PDU not matching any PDRs.
+                 */
+                if (ogs_time_ntp32_now() >
+                       (ogs_pfcp_self()->local_recovery +
+                        ogs_time_sec(
+                            ogs_app()->time.message.pfcp.association_interval))) {
+                    ogs_error(
+                            "[%s] Send Error Indication [TEID:0x%x] to [%s]",
+                            OGS_ADDR(&sock->local_addr, buf1),
+                            teid,
+                            OGS_ADDR(&from, buf2));
+                    ogs_gtp1_send_error_indication(sock, teid, qfi, &from);
+                }
                 goto cleanup;
             }
 
@@ -684,7 +727,7 @@ int upf_gtp_init(void)
 
     config.cluster_2048_pool = ogs_app()->pool.packet;
 
-#if OGS_USE_TALLOC
+#if OGS_USE_TALLOC == 1
     /* allocate a talloc pool for GTP to ensure it doesn't have to go back
      * to the libc malloc all the time */
     packet_pool = talloc_pool(__ogs_talloc_core, 1000*1024);
